---
label: HERDING_SPIKES_2
dockerfile: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/herdingspikes2/container/Dockerfile
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/herdingspikes2/herdingspikes2.py
notes: 
website: https://github.com/mhhennig/HS2
source_code: https://github.com/mhhennig/HS2
authors: Matthias Hennig, Jano Horvath, Cole Hurwitz, Oliver Muthmann, Albert Puente Encinas, Martino Sorbaro, Cesar Juarez Ramirez, and Raimon Wintzer
processor_name: HerdingSpikes2
doi: 10.3389/fninf.2015.00028
---

# HERDING_SPIKES_2

## Description

*From the HerdingSpikes2 website*: This software provides functionality for high density electrophysiology. Detection, localisation and clustering of spike data from dense multielectrode arrays.

## References
[1] J.-O. Muthmann, H. Amin, E. Sernagor, A. Maccione, D. Panas, L. Berdondini, U.S. Bhalla, M.H. Hennig MH (2015). [Spike detection for large neural populations using high density multielectrode arrays](http://journal.frontiersin.org/article/10.3389/fninf.2015.00028/abstract). Front. Neuroinform. 9:28. doi: 10.3389/fninf.2015.00028.

[2] G. Hilgen, M. Sorbaro, S. Pirmoradian, J.-O. Muthmann, I. Kepiro, S. Ullo, C. Juarez Ramirez, A. Puente Encinas, A. Maccione, L. Berdondini, V. Murino, D. Sona, F. Cella Zanacchi, E. Sernagor, M.H. Hennig (2016). [Unsupervised spike sorting for large scale, high density multielectrode arrays.](http://www.cell.com/cell-reports/fulltext/S2211-1247(17)30236-X) Cell Reports 18, 2521–2532. bioRxiv: <http://dx.doi.org/10.1101/048645>.

